@@ -3,15 +3,21 @@
 #' @name cohortBuilder-package
 #' @importFrom magrittr %>%
 #' @importFrom dplyr sym
+NULL
 
 globalVariables(c(
   ":=", "!!", ".data",
   "arrow_end_position_y", "excl_end_position_x", "excl_position_x",
   "excl_position_y", "label", "label_excl",
-  "label_heights", "label_position_x", "label_position_y", "level"
+  "label_heights", "label_position_x", "label_position_y", "level",
+  "dataset", "type", "expr", "new_expr", "expr1", "!<-", "x"
 ))
 
-NULL
+force_import <- function() {
+  R6::R6Class
+  formatR::tidy_source
+  jsonlite::toJSON
+}
 
 `%:::%` <- function(pkg, name) {
   pkg <- as.character(substitute(pkg))
